@@ -16,7 +16,7 @@ use Plack::Util::Accessor qw/ client sample_rate /;
 use Time::HiRes;
 use Try::Tiny;
 
-our $VERSION = 'v0.3.2';
+our $VERSION = 'v0.3.3';
 
 sub call {
     my ( $self, $env ) = @_;
@@ -152,12 +152,12 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.3.2
+version v0.3.3
 
 =head1 SYNOPSIS
 
   use Plack::Builder;
-  use Net::Statsd::Client;
+  use Net::Statsd::Tiny;
 
   builder {
 
